@@ -2,7 +2,7 @@ import asyncio
 import gtm_agent
 
 async def main():
-    await (gtm_agent.start("/Users/rosamii1/opllm-generic-agents/sample/sample.csv"))
+    await (gtm_agent.start("/Users/rosamii1/opllm-generic-agents/sample/sample.csv", 0))
 
 if __name__ == "__main__":
     asyncio.run(main())
\ No newline at end of file
