@@ -104,41 +104,41 @@ async def fill_template(email_list: list[str]) -> list[str]:
     return template_list
 
 @mcp.tool()
-async def continue_email_generation(next_email: int, res: FileResource):
-    next_email += 1
-    await generate_email(res, next_email)
+async def continue_email_generation(res: FileResource, row_number: int):
+    row_number += 1
+    file_path = os.path.join(os.path.dirname(__file__), res.path)
+    result = await generate_email(file_path, row_number)
+    return result
 
 @mcp.tool()
 async def start_email_generation(res: FileResource):
-    await generate_email(res, 0)
+    file_path = os.path.join(os.path.dirname(__file__), res.path)
+    result = await generate_email(file_path, 0)
+    return result
 
-@mcp.tool()
-async def generate_email(res: FileResource, row_number: int):
-    email = ""
+async def generate_email(file_path: str, row_number: int) -> str:
+    email = "Email"
     try:
-        with open(res.path, mode="r", encoding="latin-1") as file:
+        with open(file_path, mode="r", encoding="latin-1") as file:
             csv_reader = csv.reader(file)
-            next(csv_reader)  # Skip the header row
+            next(csv_reader)
 
             processed = 0
             errors = 0
-
-            for row in enumerate(csv_reader, start=1):
+            for i, row in enumerate(csv_reader, start=1):
                 try:
+                    print(row)
+                    print(row_number)
                     if len(row) < 6:  # Check if row has enough columns
                         print(f"Row {row_number}: Skipping - insufficient data")
                         continue
 
-                    result = await gtm_agent.generate_mail(row, row_number)
-                    email += f"Generated email:\n{result}"
+                    result = await asyncio.wait_for(gtm_agent.generate_mail(row, row_number))
+
+                    email = f"Generated email:\n{result}"
+                    print(email)
                     processed += 1
-
-                    # Add delay to prevent overwhelming the system
-                    await asyncio.sleep(1)
-
-                    # Progress indicator
-                    if processed % 5 == 0:
-                        print(f"Progress: {processed} emails processed")
+                    break
 
                 except Exception as e:
                     errors += 1
@@ -147,7 +147,8 @@ async def generate_email(res: FileResource, row_number: int):
 
             print(f"Processing complete: {processed} emails processed, {errors} errors")
 
-            return email, res, row_number
+
+            return email
 
     except Exception as e:
         print(f"Error in process_emails: {e}")
